local MAJOR_VERSION = "Threat-1.0"
local MINOR_VERSION = tonumber(("$Revision: 39782 $"):match("%d+"))

if MINOR_VERSION > _G.ThreatLib_MINOR_VERSION then
	_G.ThreatLib_MINOR_VERSION = MINOR_VERSION
end

ThreatLib_funcs[#ThreatLib_funcs+1] = function()

local ThreatLib = _G.ThreatLib

local BB = AceLibrary("Babble-Boss-2.2")

ThreatLib:GetModule("NPCCore"):RegisterModule(BB["Leotheras the Blind"], BB["Shadow of Leotheras"], function(Leotheras)
	Leotheras:RegisterTranslation("enUS", function() return {
		["I am in control now!"] = "I am in control now!",
		["I am the master! Do you hear?"] = "I am the master! Do you hear?",
		["Finally, my banishment ends!"] = "Finally, my banishment ends!",
		["Leotheras the Blind gains Whirlwind"] = "Leotheras the Blind gains Whirlwind"
	} end)

	Leotheras:RegisterTranslation("deDE", function() return {
		["I am in control now!"] = "Ich habe jetzt die Kontrolle!",
		["I am the master! Do you hear?"] = "Ich bin der Meister! H\195\182rt Ihr?",
		["Finally, my banishment ends!"] = "Endlich hat meine Verbannung ein Ende!",
		["Leotheras the Blind gains Whirlwind"] = "Leotheras der Blinde bekommt Wirbelwind"
	} end)

	Leotheras:RegisterTranslation("frFR", function() return {
		["I am in control now!"] = "Je prends le contrôle !",
		["I am the master! Do you hear?"] = "C'est moi le maître ! Vous entendez ?",
		["Finally, my banishment ends!"] = "Enfin, mon exil s'achève !",
		["Leotheras the Blind gains Whirlwind"] = "Leotheras l'Aveugle gagne Tourbillon"
	} end)

	Leotheras:RegisterTranslation("koKR", function() return {
		["I am in control now!"] = "꺼져라, 엘프 꼬맹이. 지금부터는 내가 주인이다!",
		["I am the master! Do you hear?"] = "누구나 마음속에 악마를 품고 살지...",
		["Finally, my banishment ends!"] = "드디어, 내가 풀려났도다!",
		["Leotheras the Blind gains Whirlwind"] = "눈먼 레오테라스|1이;가; 소용돌이 효과를 얻었습니다."
	} end)

	Leotheras:RegisterTranslation("zhTW", function() return {
		["I am in control now!"] = nil,
		["I am the master! Do you hear?"] = nil,
		["Finally, my banishment ends!"] = nil,
		["Leotheras the Blind gains Whirlwind"] = nil
	} end)

	local whirlwindTrigger = Leotheras:GetTranslation("Leotheras the Blind gains Whirlwind") or ""
	local demonPhase = Leotheras:GetTranslation("I am in control now!")
	local splitPhase = Leotheras:GetTranslation("I am the master! Do you hear?")
	local initialPhase = Leotheras:GetTranslation("Finally, my banishment ends!")

	Leotheras:UnregisterTranslations()

	function Leotheras:Init()
		if not whirlwindTrigger then
			error(string.format("No ThreatLib localization available for %s in locale %s", BB["Leotheras the Blind"], locale))
		end

		self:RegisterCombatant(BB["Leotheras the Blind"], true)
		self:RegisterCombatant(BB["Shadow of Leotheras"], false)

		-- To register a callback to a yell or emote:
		-- self:RegisterChatEvent([yell|event], localizedMobName, yellOrEmoteToTriggerOn, callbackFunction)

		self:RegisterChatEvent("yell", BB["Leotheras the Blind"], demonPhase, self.demonTransition)
		self:RegisterChatEvent("yell", BB["Leotheras the Blind"], splitPhase, self.splitTransition)
		self:RegisterChatEvent("yell", BB["Shadow of Leotheras"], splitPhase, self.splitTransition)		--I'm not sure if the shadow or leo himself does the yell
		self:RegisterChatEvent("yell", BB["Leotheras the Blind"], initialPhase, self.humanTransition)
	end

	function Leotheras:demonTransition()
		self:SetNumberOfMobs(1)
		self:WipeRaidThreatOnMob(BB["Leotheras the Blind"])
		self:WipeRaidThreatOnMob(BB["Shadow of Leotheras"])
		if not self:IsEventScheduled("LeotherasDemonTimer") then
			self:ScheduleEvent("LeotherasDemonTimer", self.humanTransition, 60, self)
		end
		if self:IsEventScheduled("LeotherasWhirlwindTimer") then
			self:CancelScheduledEvent("LeotherasWhirlwindTimer")
		end
	end

	function Leotheras:humanTransition()
		self:WipeRaidThreatOnMob(BB["Leotheras the Blind"])
	end

	function Leotheras:StartFight()
		self:SetNumberOfMobs(1)
	end

	function Leotheras:splitTransition()
		self:SetNumberOfMobs(2)		-- Leotheras + Shadow of Leotheras
		self:WipeRaidThreatOnMob(BB["Leotheras the Blind"])
		self:WipeRaidThreatOnMob(BB["Shadow of Leotheras"])
		if self:IsEventScheduled("LeotherasDemonTimer") then
			self:CancelScheduledEvent("LeotherasDemonTimer")
		end
		if self:IsEventScheduled("LeotherasWhirlwindTimer") then
			self:CancelScheduledEvent("LeotherasWhirlwindTimer")
		end
	end

	function Leotheras:OnEnable()
		-- This is really, really, really probably the wrong way to do this.
		ThreatLib:GetModule("NPCCore").modulePrototype.OnEnable(self)
		self:RegisterEvent("CHAT_MSG_SPELL_PERIODIC_CREATURE_BUFFS")
	end

	function Leotheras:CHAT_MSG_SPELL_PERIODIC_CREATURE_BUFFS(msg)
		if msg:find(whirlwindTrigger) then
			if not self:IsEventScheduled("LeotherasWhirlwindTimer") then
				-- The WW is 12 sec, but observationally, it seems that threat is cleared when the WW ticks
				-- So, we'll clear it right before the last tick of the WW, since tanks can sometimes pick him up
				-- right before the WW fades.
				self:ScheduleEvent("LeotherasWhirlwindTimer", self.humanTransition, 11, self)
			end
		end
	end
end)

table.insert(ThreatLib.UpvalueFixers, function(lib)
	ThreatLib = lib
end)

end